#include "Adafruit_VL53L0X.h"
#include <Servo.h>

// address we will assign if dual sensor is present
#define LOX1_ADDRESS 0x30
#define LOX2_ADDRESS 0x31

// set the pins to shutdown
#define SHT_LOX1 7
#define SHT_LOX2 6

Servo myservo1;
Servo myservo2;

int servoPin1 = 8;
int servoPin2 = 9;
int angle = 0;
int vitesse = 2;

// objects for the vl53l0x
Adafruit_VL53L0X lox1 = Adafruit_VL53L0X();
Adafruit_VL53L0X lox2 = Adafruit_VL53L0X();

// this holds the measurement
VL53L0X_RangingMeasurementData_t measure1;
VL53L0X_RangingMeasurementData_t measure2;

/*
  Bon alors là il faut faire de la magie noire parce que la librairie de ADAFRUIT a été faite n'importe comment. 
  En gros il faut reprogrammer un pin qui sert à rien (XSHUT) 
  pour pouvoir les contrôler indépendament parce qu'ADAFRUIT ne permet pas de choisir le pin. Super. 
 */
void setID() {
  // all reset
  digitalWrite(SHT_LOX1, LOW);    
  digitalWrite(SHT_LOX2, LOW);
  delay(10);
  // all unreset
  digitalWrite(SHT_LOX1, HIGH);
  digitalWrite(SHT_LOX2, HIGH);
  delay(10);

  // activating LOX1 and resetting LOX2
  digitalWrite(SHT_LOX1, HIGH);
  digitalWrite(SHT_LOX2, LOW);

  // initing LOX1
  if(!lox1.begin(LOX1_ADDRESS)) {
    Serial.println(F("Failed to boot first VL53L0X"));
    while(1);
  }
  delay(10);

  // activating LOX2
  digitalWrite(SHT_LOX2, HIGH);
  delay(10);

  //initing LOX2
  if(!lox2.begin(LOX2_ADDRESS)) {
    Serial.println(F("Failed to boot second VL53L0X"));
    while(1);
  }
}

void read_dual_sensors() {
  
  lox1.rangingTest(&measure1, false); // pass in 'true' to get debug data printout!
  lox2.rangingTest(&measure2, false); // pass in 'true' to get debug data printout!

  // print sensor one reading
  Serial.print(F("1: "));
  if(measure1.RangeStatus != 4) {     // if not out of range
    Serial.print(measure1.RangeMilliMeter);
  } else {
    Serial.print(F("Out of range"));
  }
  
  Serial.print(F(" "));

  // print sensor two reading
  Serial.print(F("2: "));
  if(measure2.RangeStatus != 4) {
    Serial.print(measure2.RangeMilliMeter);
  } else {
    Serial.print(F("Out of range"));
  }
  Serial.println();
  // 1 : gauche, 2 : droite

  bool droite = false; //Y'a un truc à droite ?
  bool gauche = false; //Y'a un truc à gauche ?
  
  if (measure1.RangeStatus != 4 && measure1.RangeMilliMeter != 8191) {
    gauche = true;
    Serial.print(F("\t Something left"));
  }
  if (measure2.RangeStatus != 4 && measure2.RangeMilliMeter != 8191) {
    droite = true;
    Serial.print(F("\t Something right"));
  }

  // faut tourner à droite
  if (droite && !gauche) {
    if (angle > 0) {
      angle -= vitesse;
      myservo1.write(angle);
      myservo2.write(angle);
      Serial.print(F("\t Turn right"));
    }
  } // faut tourner à gauche
  else if (gauche && !droite) {
    if (angle < 180) {
      angle += vitesse;
      myservo1.write(angle);
      myservo2.write(angle);
      Serial.print(F("\t Turn left"));
    }
  }
}

void setup() {
  Serial.begin(115200);

  // wait until serial port opens for native USB devices
  while (! Serial) { delay(1); }

  pinMode(SHT_LOX1, OUTPUT);
  pinMode(SHT_LOX2, OUTPUT);

  Serial.println(F("Shutdown pins inited..."));

  digitalWrite(SHT_LOX1, LOW);
  digitalWrite(SHT_LOX2, LOW);

  Serial.println(F("Both in reset mode...(pins are low)"));
  
  myservo1.attach(servoPin1);
  myservo2.attach(servoPin2);

  Serial.println(F("Starting..."));
  setID();
  
  myservo1.write(90);
  myservo2.write(90);
  angle = 90;
  
}

void loop() {
  read_dual_sensors();
  delay(50);
}
